@@ -1,8 +1,17 @@
 #' Continuous integration setup and badges
 #'
-#' Sets up continuous integration (CI) services for an R package that is
-#' developed on GitHub. CI services can run `R CMD check` automatically on
-#' various platforms, triggered by each push or pull request. These functions
+#' @description
+#'
+#' `r lifecycle::badge("deprecated")`
+#'
+#' Some of these functions are now soft-deprecated since the tidyverse team has
+#' started using [GitHub Actions (GHA)](https://github.com/features/actions) for
+#' continuous integration (CI). See [use_github_actions()] for help configuring
+#' GHA. GHA functionality in usethis is actively maintained and exercised, which
+#' is no longer true for Travis-CI or AppVeyor.
+#'
+#' Sets up third-party continuous integration (CI) services for an R package
+#' that is developed on GitHub or, perhaps, GitLab. These functions
 #' * Add service-specific configuration files and add them to `.Rbuildignore`.
 #' * Activate a service or give the user a detailed prompt.
 #' * Provide the markdown to insert a badge into README.
@@ -21,8 +30,14 @@ NULL
 #'   https://travis-ci.com. Change to `"org"` for https://travis-ci.org.
 #' @export
 #' @rdname ci
-use_travis <- function(browse = rlang::is_interactive(), ext = c("com", "org")) {
-  check_uses_github()
+use_travis <- function(browse = rlang::is_interactive(),
+                       ext = c("com", "org")) {
+  lifecycle::deprecate_soft(
+    when = "2.0.0",
+    what = "usethis::use_travis()",
+    with = "use_github_actions()"
+  )
+  repo_spec <- target_repo_spec()
   ext <- arg_match(ext)
   new <- use_template(
     "travis.yml",
@@ -32,51 +47,40 @@ use_travis <- function(browse = rlang::is_interactive(), ext = c("com", "org"))
   if (!new) {
     return(invisible(FALSE))
   }
+  use_travis_badge(ext = ext, repo_spec = repo_spec)
+  travis_activate(repo_spec, browse = browse, ext = ext)
 
-  travis_activate(browse, ext = ext)
-  use_travis_badge(ext = ext)
   invisible(TRUE)
 }
 
 #' @section `use_travis_badge()`:
 #' Only adds the [Travis CI](https://travis-ci.com/) badge. Use for a project
 #'  where Travis is already configured.
+#' @eval param_repo_spec()
 #' @export
 #' @rdname ci
-use_travis_badge <- function(ext = c("com", "org")) {
-  check_uses_github()
+use_travis_badge <- function(ext = c("com", "org"), repo_spec = NULL) {
+  repo_spec <- repo_spec %||% target_repo_spec()
   ext <- arg_match(ext)
-  url <- glue("https://travis-ci.{ext}/{github_repo_spec()}")
-  img <- glue("{url}.svg?branch=master")
+  url <- glue("https://travis-ci.{ext}/{repo_spec}")
+  img <- glue("{url}.svg?branch={git_branch_default()}")
   use_badge("Travis build status", url, img)
 }
 
-travis_activate <- function(browse = is_interactive(), ext = c("com", "org")) {
+travis_activate <- function(repo_spec,
+                            browse = is_interactive(),
+                            ext = c("com", "org")) {
   ext <- arg_match(ext)
-  url <- glue("https://travis-ci.{ext}/profile/{github_owner()}")
+  url <- glue("https://travis-ci.{ext}/profile/{repo_spec}")
 
-  ui_todo("Turn on travis for your repo at {url}")
+  ui_todo("Turn on travis for the repo at {url}")
   if (browse) {
     utils::browseURL(url)
   }
 }
 
-uses_travis <- function(base_path = proj_get()) {
-  path <- glue("{base_path}/.travis.yml")
-  file_exists(path)
-}
-
-check_uses_travis <- function(base_path = proj_get()) {
-  if (uses_travis(base_path)) {
-    return(invisible())
-  }
-
-  ui_stop(
-    "
-    Cannot detect that package {ui_value(project_name(base_path))} already uses Travis.
-    Do you need to run {ui_code('use_travis()')}?
-    "
-  )
+uses_travis <- function() {
+  file_exists(proj_path(".travis.yml"))
 }
 
 #' @section `use_appveyor()`:
@@ -86,15 +90,19 @@ check_uses_travis <- function(base_path = proj_get()) {
 #' @export
 #' @rdname ci
 use_appveyor <- function(browse = rlang::is_interactive()) {
-  check_uses_github()
-
+  lifecycle::deprecate_soft(
+    when = "2.0.0",
+    what = "usethis::use_appveyor()",
+    with = "use_github_actions()"
+  )
+  repo_spec <- target_repo_spec()
   new <- use_template("appveyor.yml", ignore = TRUE)
   if (!new) {
     return(invisible(FALSE))
   }
 
+  use_appveyor_badge(repo_spec)
   appveyor_activate(browse)
-  use_appveyor_badge()
 
   invisible(TRUE)
 }
@@ -112,26 +120,20 @@ appveyor_activate <- function(browse = is_interactive()) {
 #'  where AppVeyor is already configured.
 #' @export
 #' @rdname ci
-use_appveyor_badge <- function() {
-  appveyor <- appveyor_info()
-  use_badge("AppVeyor build status", appveyor$url, appveyor$img)
-}
-
-appveyor_info <- function() {
-  check_uses_github()
+use_appveyor_badge <- function(repo_spec = NULL) {
+  repo_spec <- repo_spec %||% target_repo_spec()
   img <- glue(
     "https://ci.appveyor.com/api/projects/status/github/",
-    "{github_repo_spec()}?branch=master&svg=true"
+    "{repo_spec}?branch={git_branch_default()}&svg=true"
   )
-  url <- glue("https://ci.appveyor.com/project/{github_repo_spec()}")
-
-  list(url = url, img = img)
+  url <- glue("https://ci.appveyor.com/project/{repo_spec}")
+  use_badge("AppVeyor build status", url, img)
 }
 
 #' @section `use_gitlab_ci()`:
-#' Adds a basic `.gitlab-ci.yml` to the top-level directory of a package. This is
-#' a configuration file for the [GitLab CI/CD](https://docs.gitlab.com/ee/ci/) continuous
-#' integration service for GitLab.
+#' Adds a basic `.gitlab-ci.yml` to the top-level directory of a package. This
+#' is a configuration file for the [GitLab
+#' CI/CD](https://docs.gitlab.com/ee/ci/) continuous integration service.
 #' @export
 #' @rdname ci
 use_gitlab_ci <- function() {
@@ -148,39 +150,22 @@ use_gitlab_ci <- function() {
   invisible(TRUE)
 }
 
-uses_gitlab_ci <- function(base_path = proj_get()) {
-  path <- path(base_path, ".gitlab-ci.yml")
-  file_exists(path)
-}
-
-check_uses_gitlab_ci <- function(base_path = proj_get()) {
-  if (uses_gitlab_ci(base_path)) {
-    return(invisible())
-  }
-
-  ui_stop(
-    "
-    Cannot detect that package {ui_value(project_name(base_path))} already uses GitLab CI.
-    Do you need to run {ui_code('use_gitlab_ci()')}?
-    "
-  )
-}
-
 #' @section `use_circleci()`:
-#' Adds a basic `.circleci/config.yml` to the top-level directory of a package. This is a
-#' configuration file for the [CircleCI](https://circleci.com/) continuous
-#' integration service.
+#' Adds a basic `.circleci/config.yml` to the top-level directory of a package.
+#' This is a configuration file for the [CircleCI](https://circleci.com/)
+#' continuous integration service.
 #' @param image The Docker image to use for build. Must be available on
 #'   [DockerHub](https://hub.docker.com). The
-#'   [rocker/verse](https://hub.docker.com/r/rocker/verse) image includes TeX
-#'   Live, pandoc, and the tidyverse packages. For a minimal image, try
+#'   [rocker/verse](https://hub.docker.com/r/rocker/verse) image includes
+#'   TeXLive, pandoc, and the tidyverse packages. For a minimal image, try
 #'   [rocker/r-ver](https://hub.docker.com/r/rocker/r-ver). To specify a version
 #'   of R, change the tag from `latest` to the version you want, e.g.
 #'   `rocker/r-ver:3.5.3`.
 #' @export
 #' @rdname ci
-use_circleci <- function(browse = rlang::is_interactive(), image = "rocker/verse:latest") {
-  check_uses_github()
+use_circleci <- function(browse = rlang::is_interactive(),
+                         image = "rocker/verse:latest") {
+  repo_spec <- target_repo_spec()
   use_directory(".circleci", ignore = TRUE)
   new <- use_template(
     "circleci-config.yml",
@@ -192,47 +177,28 @@ use_circleci <- function(browse = rlang::is_interactive(), image = "rocker/verse
     return(invisible(FALSE))
   }
 
-  circleci_activate(browse)
-  use_circleci_badge()
+  use_circleci_badge(repo_spec)
+  circleci_activate(spec_owner(repo_spec), browse)
+
   invisible(TRUE)
 }
 
 #' @section `use_circleci_badge()`:
 #' Only adds the [Circle CI](https://circleci.com/) badge. Use for a project
 #'  where Circle CI is already configured.
-#' @export
 #' @rdname ci
 #' @export
-use_circleci_badge <- function() {
-  check_uses_github()
-  url <- glue("https://circleci.com/gh/{github_repo_spec()}")
+use_circleci_badge <- function(repo_spec = NULL) {
+  repo_spec <- repo_spec %||% target_repo_spec()
+  url <- glue("https://circleci.com/gh/{repo_spec}")
   img <- glue("{url}.svg?style=svg")
   use_badge("CircleCI build status", url, img)
 }
 
-circleci_activate <- function(browse = is_interactive()) {
-  url <- glue("https://circleci.com/add-projects/gh/{github_owner()}")
-
+circleci_activate <- function(owner, browse = is_interactive()) {
+  url <- glue("https://circleci.com/add-projects/gh/{owner}")
   ui_todo("Turn on CircleCI for your repo at {url}")
   if (browse) {
     utils::browseURL(url)
   }
 }
-
-uses_circleci <- function(base_path = proj_get()) {
-  path <- glue("{base_path}/.circleci/config.yml")
-  file_exists(path)
-}
-
-check_uses_circleci <- function(base_path = proj_get()) {
-  if (uses_circleci(base_path)) {
-    return(invisible())
-  }
-
-  ui_stop(
-    "
-    Cannot detect that package {ui_field(project_name(base_path))} already uses CircleCI.
-    Do you need to run {ui_code('use_circleci()')}?
-    "
-  )
-}
