@@ -10,9 +10,9 @@
 #' If your package is going to CRAN, the link to the CoC in your README must
 #' be an absolute link to a rendered website as `CODE_OF_CONDUCT.md` is not
 #' included in the package sent to CRAN. `use_code_of_conduct()` will
-#' automatically generate this link if you use pkgdown and have set the
-#' `url` field in `pkgdown.yml`; otherwise it'll link to
-#' <https://www.contributor-covenant.org/version/2/0/code_of_conduct/>.
+#' automatically generate this link if (1) you use pkgdown and (2) have set the
+#' `url` field in `_pkgdown.yml`; otherwise it will link to a copy of the CoC
+#' on <https://www.contributor-covenant.org>.
 #'
 #' @param path Path of the directory to put `CODE_OF_CONDUCT.md` in, relative to
 #'   the active project. Passed along to [use_directory()]. Default is to locate
@@ -31,14 +31,17 @@ use_code_of_conduct <- function(path = NULL) {
     ignore = is_package() && is.null(path)
   )
 
-  href <- project_pkgdown_url() %||% "https://contributor-covenant.org/version/2/0"
+  href <- pkgdown_url(pedantic = TRUE) %||%
+    "https://contributor-covenant.org/version/2/0"
   href <- paste0(href, "/CODE_OF_CONDUCT.html")
 
   ui_todo("Don't forget to describe the code of conduct in your README:")
   ui_code_block("
     ## Code of Conduct
 
-    Please note that the {project_name()} project is released with a [Contributor Code of Conduct]({href}). By contributing to this project, you agree to abide by its terms."
+    Please note that the {project_name()} project is released with a \\
+    [Contributor Code of Conduct]({href}). By contributing to this project, \\
+    you agree to abide by its terms."
   )
 
   invisible(new)
