@@ -22,20 +22,20 @@
 #' * `good first issue` indicates a good issue for first-time contributors.
 #' * `help wanted` indicates that a maintainer wants help on an issue.
 #'
-#' @param repo_spec Optional repository specification (`owner/repo`) if you
-#'   don't want to target the current project.
+#' @param repo_spec,host,auth_token `r lifecycle::badge("deprecated")`: These
+#'   arguments are now deprecated and will be removed in the future. Any input
+#'   provided via these arguments is not used. The target repo, host, and auth
+#'   token are all now determined from the current project's Git remotes.
 #' @param labels A character vector giving labels to add.
 #' @param rename A named vector with names giving old names and values giving
 #'   new names.
 #' @param colours,descriptions Named character vectors giving hexadecimal
 #'   colours (like `e02a2a`) and longer descriptions. The names should match
-#'   label names, and anything unmatched will be left unchanged. If you
-#'   create a new label, and don't supply colours, it will be given a random
-#'   colour.
-#' @param delete_default If `TRUE`, removes GitHub default labels that do
-#'   not appear in the `labels` vector and that do not have associated issues.
+#'   label names, and anything unmatched will be left unchanged. If you create a
+#'   new label, and don't supply colours, it will be given a random colour.
+#' @param delete_default If `TRUE`, removes GitHub default labels that do not
+#'   appear in the `labels` vector and that do not have associated issues.
 #'
-#' @inheritParams use_github_links
 #' @export
 #' @examples
 #' \dontrun{
@@ -56,35 +56,34 @@
 #'   descriptions = c("foofiest" = "the foofiest issue you ever saw")
 #' )
 #' }
-use_github_labels <- function(repo_spec = github_repo_spec(),
+use_github_labels <- function(repo_spec = deprecated(),
                               labels = character(),
                               rename = character(),
                               colours = character(),
                               descriptions = character(),
                               delete_default = FALSE,
-                              auth_token = github_token(),
-                              host = NULL) {
-  if (missing(repo_spec)) {
-    check_uses_github()
+                              host = deprecated(),
+                              auth_token = deprecated()) {
+  if (lifecycle::is_present(repo_spec)) {
+    deprecate_warn_repo_spec("use_github_labels")
   }
-  check_github_token(auth_token)
-
-  gh <- function(endpoint, ...) {
-    gh::gh(
-      endpoint,
-      ...,
-      owner = spec_owner(repo_spec),
-      repo = spec_repo(repo_spec),
-      .token = auth_token,
-      .api_url = host,
-      .send_headers = c(
-        "Accept" = "application/vnd.github.symmetra-preview+json"
-      )
-    )
+  if (lifecycle::is_present(host)) {
+    deprecate_warn_host("use_github_labels")
+  }
+  if (lifecycle::is_present(auth_token)) {
+    deprecate_warn_auth_token("use_github_labels")
   }
 
-  cur_labels <- gh("GET /repos/:owner/:repo/labels")
-  label_attr <- function(x, l, mapper = purrr::map_chr) {
+  tr <- target_repo(github_get = TRUE)
+  if (!isTRUE(tr$can_push)) {
+    ui_stop("
+      You don't seem to have push access for {ui_value(tr$repo_spec)}, which \\
+      is required to modify labels.")
+  }
+  gh <- gh_tr(tr)
+
+  cur_labels <- gh("GET /repos/{owner}/{repo}/labels")
+  label_attr <- function(x, l, mapper = map_chr) {
     mapper(l, x, .default = NA)
   }
 
@@ -102,18 +101,18 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
     # Fails if "new_label_name" already exists
     # https://github.com/r-lib/usethis/issues/551
     # Must first PATCH issues, then sort out labels
-    issues <- purrr::map(
+    issues <- map(
       to_rename,
-      ~ gh("GET /repos/:owner/:repo/issues", labels = .x)
+      ~ gh("GET /repos/{owner}/{repo}/issues", labels = .x)
     )
     issues <- purrr::flatten(issues)
-    number <- purrr::map_int(issues, "number")
-    old_labels <- purrr::map(issues, "labels")
+    number <- map_int(issues, "number")
+    old_labels <- map(issues, "labels")
     df <- data.frame(
       number = rep.int(number, lengths(old_labels))
     )
     df$labels <- purrr::flatten(old_labels)
-    df$labels <- purrr::map_chr(df$labels, "name")
+    df$labels <- map_chr(df$labels, "name")
 
     # enact relabelling
     m <- match(df$labels, names(rename))
@@ -123,7 +122,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
     purrr::iwalk(
       new_labels,
       ~ gh(
-        "PATCH /repos/:owner/:repo/issues/:issue_number",
+        "PATCH /repos/{owner}/{repo}/issues/{issue_number}",
         issue_number = .y,
         labels = I(.x)
       )
@@ -132,14 +131,14 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
     # issues have correct labels now; safe to edit labels themselves
     purrr::walk(
       to_rename,
-      ~ gh("DELETE /repos/:owner/:repo/labels/:name", name = .x)
+      ~ gh("DELETE /repos/{owner}/{repo}/labels/{name}", name = .x)
     )
     labels <- union(labels, setdiff(rename, cur_label_names))
   } else {
     ui_info("No labels need renaming")
   }
 
-  cur_labels <- gh("GET /repos/:owner/:repo/labels")
+  cur_labels <- gh("GET /repos/{owner}/{repo}/labels")
   cur_label_names <- label_attr("name", cur_labels)
 
   # Add missing labels
@@ -151,7 +150,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
 
     for (label in to_add) {
       gh(
-        "POST /repos/:owner/:repo/labels",
+        "POST /repos/{owner}/{repo}/labels",
         name = label,
         color = purrr::pluck(colours, label, .default = random_colour()),
         description = purrr::pluck(descriptions, label, .default = "")
@@ -159,7 +158,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
     }
   }
 
-  cur_labels <- gh("GET /repos/:owner/:repo/labels")
+  cur_labels <- gh("GET /repos/{owner}/{repo}/labels")
   cur_label_names <- label_attr("name", cur_labels)
 
   # Update colours
@@ -174,7 +173,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
 
     for (label in to_update) {
       gh(
-        "PATCH /repos/:owner/:repo/labels/:name",
+        "PATCH /repos/{owner}/{repo}/labels/{name}",
         name = label,
         color = colours[[label]]
       )
@@ -193,7 +192,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
 
     for (label in to_update) {
       gh(
-        "PATCH /repos/:owner/:repo/labels/:name",
+        "PATCH /repos/{owner}/{repo}/labels/{name}",
         name = label,
         description = descriptions[[label]]
       )
@@ -202,18 +201,18 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
 
   # Delete unused default labels
   if (delete_default) {
-    default <- purrr::map_lgl(cur_labels, "default")
+    default <- map_lgl(cur_labels, "default")
     to_remove <- setdiff(cur_label_names[default], labels)
 
     if (length(to_remove) > 0) {
       ui_done("Removing default labels: {ui_value(to_remove)}")
 
       for (label in to_remove) {
-        issues <- gh("GET /repos/:owner/:repo/issues", labels = label)
+        issues <- gh("GET /repos/{owner}/{repo}/issues", labels = label)
         if (length(issues) > 0) {
           ui_todo("Delete {ui_value(label)} label manually; it has associated issues")
         } else {
-          gh("DELETE /repos/:owner/:repo/labels/:name", name = label)
+          gh("DELETE /repos/{owner}/{repo}/labels/{name}", name = label)
         }
       }
     }
@@ -222,18 +221,25 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
 
 #' @export
 #' @rdname use_github_labels
-use_tidy_labels <- function(repo_spec = github_repo_spec(),
-                            auth_token = github_token(),
-                            host = NULL) {
+use_tidy_labels <- function(repo_spec = deprecated(),
+                            host = deprecated(),
+                            auth_token = deprecated()) {
+  if (lifecycle::is_present(repo_spec)) {
+    deprecate_warn_repo_spec("use_tidy_labels")
+  }
+  if (lifecycle::is_present(host)) {
+    deprecate_warn_host("use_tidy_labels")
+  }
+  if (lifecycle::is_present(auth_token)) {
+    deprecate_warn_auth_token("use_tidy_labels")
+  }
+
   use_github_labels(
-    repo_spec = repo_spec,
     labels = tidy_labels(),
     rename = tidy_labels_rename(),
     colours = tidy_label_colours(),
     descriptions = tidy_label_descriptions(),
-    delete_default = TRUE,
-    auth_token = auth_token,
-    host = host
+    delete_default = TRUE
   )
 }
 
