@@ -45,12 +45,11 @@ use_logo <- function(img, geometry = "240x278", retina = TRUE) {
 
   pkg <- project_name()
   if (retina) {
-    height <- height / 2
+    height <- round(height / 2)
   }
 
   ui_todo("Add logo to your README with the following html:")
-
-  pd_link <- pkgdown_link()
+  pd_link <- pkgdown_url(pedantic = TRUE)
   if (is.null(pd_link)) {
     ui_code_block("# {pkg} <img src={ui_path(logo_path)} align=\"right\" height=\"{height}\" />")
   } else {
